<?php
/*
 * Laconica - a distributed open-source microblogging tool
 * Copyright (C) 2008, Controlez-Vous, Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

if (!defined('LACONICA')) { exit(1); }

require_once(INSTALLDIR.'/lib/stream.php');

class PublicAction extends StreamAction {

	function handle($args) {
		parent::handle($args);

		$page = ($this->arg('page')) ? ($this->arg('page')+0) : 1;

		common_show_header(_t('Public timeline'), array($this, 'show_header'));

		# XXX: Public sidebar here?

		$this->show_notices($page);

		common_show_footer();
	}

	function show_header() {
		common_element('link', array('rel' => 'alternate',
									 'href' => common_local_url('publicrss'),
									 'type' => 'application/rss+xml',
									 'title' => _t('Public Stream Feed')));
	}
	
	function show_notices($page) {

		$notice = DB_DataObject::factory('notice');

		# XXX: filter out private notifications

		$notice->orderBy('created DESC');
		
		# We fetch one extra, to see if we need an "older" link
		
		$notice->limit((($page-1)*NOTICES_PER_PAGE), NOTICES_PER_PAGE + 1);

		$cnt = $notice->find();

		common_element_start('div', 'notices');

		for ($i = 0; $i < min($cnt, NOTICES_PER_PAGE); $i++) {
			if ($notice->fetch()) {
				$this->show_notice($notice);
			} else {
				// shouldn't happen!
				break;
			}
		}

		if ($page > 1) {
			common_element_start('span', 'floatLeft width25');
			common_element('a', array('href' => common_local_url('public',
																 array('page' => $page-1)),
									  'class' => 'newer'),
						   _t('Newer'));
			common_element_end('span');
		}
		
		if ($cnt > NOTICES_PER_PAGE) {
			common_element_start('span', 'floatRight width25');
			common_element('a', array('href' => common_local_url('public',
																 array('page' => $page+1)),
									  'class' => 'older'),
						   _t('Older'));
			common_element_end('span');
		}
		common_element_end('div');
	}
}

